@@ -2,7 +2,7 @@
 package MRTG_lib;
 
 ###################################################################
-# MRTG 2.11.0  Support library MRTG_lib.pm
+# MRTG 2.11.1  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <oetiker@ee.ethz.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -1244,7 +1244,7 @@ sub targparser( $$$$ ) {
 			'@' .						# separator
 		'(?:(\[[a-fA-F0-9:]*\])|' .		# hostname as IPv6 address ($if->{HostIPv6})
 		'([-\w]+(?:\.[-\w]+)*))' .		# or DNS name ($if->{HostName})
-		'((?::[\d.]*)*)' .				# SNMP session configuration ($if->{SnmpInfo})
+		'((?::[\d.!]*)*)' .				# SNMP session configuration ($if->{SnmpInfo})
 		'(?:\|([a-zA-Z_][\w]*))?';		# numeric conversion subroutine ($if->{ConvSub})
 
 	# Match strings for simple and complex interface specifications. Entries
